summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/designer/listdnd.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdevdesigner/designer/listdnd.cpp')
-rw-r--r--kdevdesigner/designer/listdnd.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kdevdesigner/designer/listdnd.cpp b/kdevdesigner/designer/listdnd.cpp
index 7df65cbd..8431fd18 100644
--- a/kdevdesigner/designer/listdnd.cpp
+++ b/kdevdesigner/designer/listdnd.cpp
@@ -1,15 +1,15 @@
/**********************************************************************
** Copyright (C) 2002 Trolltech AS. All rights reserved.
**
** This file is part of Qt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-** information about Qt Commercial License Agreements.
+** information about TQt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
@@ -37,8 +37,8 @@ ListDnd::ListDnd( TQScrollView * eventSource, const char * name )
src->installEventFilter( this );
src->viewport()->installEventFilter( this );
- line = new TQWidget( src->viewport(), 0, Qt::WStyle_NoBorder | WStyle_StaysOnTop );
- line->setBackgroundColor( Qt::black );
+ line = new TQWidget( src->viewport(), 0, TQt::WStyle_NoBorder | WStyle_StaysOnTop );
+ line->setBackgroundColor( TQt::black );
line->resize( src->viewport()->width(), 2 );
line->hide();
}
@@ -119,7 +119,7 @@ bool ListDnd::dropEvent( TQDropEvent * )
bool ListDnd::mousePressEvent( TQMouseEvent * event )
{
- if ( event->button() == LeftButton )
+ if ( event->button() == Qt::LeftButton )
mousePressPos = event->pos();
return FALSE;
}
@@ -1,15 +1,15 @@
** Copyright (C) 2002 Trolltech AS. All rights reserved.
**
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the